@@ -31,15 +31,6 @@
 
 #include <Python.h>
 
-/*
- * There is a mis-feature somewhere with the Borland compiler.  This works
- * around it.
- */
-#if defined(__BORLANDC__)
-#include <rpc.h>
-#endif
-
-
 #ifdef __cplusplus
 extern "C" {
 #endif
